@@ -345,7 +345,7 @@ class CalibrationGraph:
     def execute(
         self,
         node: CalibrationNode,
-        protocol: CalibrationProtocol = CalibrationProtocol.OPTIMUS,
+        protocol: CalibrationProtocol = CalibrationProtocol.WAVE,
         verbosity: Verbosity = Verbosity.QUIET,
     ):
         """
@@ -358,14 +358,14 @@ class CalibrationGraph:
             The node that you want to keep to calibrated.
         protocol : CalibrationProtocol, optional
             The algorithm used to traverse the calibration graph. By default,
-            this function uses a modified version of the Optimus algorithm [1]_.
+            this function uses a modified version of the Wave algorithm [1]_.
         verbosity : Verbosity, optional
             The verbosity level of this run. Defaults to QUIET.
 
         References
         ----------
-        .. [1] `J. Kelly, P. O'Malley, M. Neeley, H. Neven, J. M. Martinis,
-               arXiv:1803.03226. <https://arxiv.org/abs/1803.03226>`_
+        .. [1] `L. Riesebos, B. Bondurant, K. R. Brown. IEEE Micro 41, 57 (2021)
+               <https://ieeexplore.ieee.org/document/9477114>`_
         """
         check_argument(
             node.in_graph(self),
